Learn R Programming

metvurst (version 0.0.1)

metvurst-package: meteorological visualistion utilities using R for science and teaching

Description

More about what it does (maybe more than one line) ~~ A concise (1-5 lines) description of the package ~~

Arguments

Details

Package:
metvurst
Type:
Package
Version:
1.0
Date:
2013-02-17
License:
GNU GPL v3
~~ An overview of how to use the package, including the most important functions ~~

References

~~ Literature or other references for background information ~~

See Also

~~ Optional links to other man pages, e.g. ~~ ~~ ~~

Examples

Run this code
~~ simple examples of the most important functions ~~

Run the code above in your browser using DataLab